;==========================================================
;READS INI FILE AND RETRIEVES VALUES (PRE 1.31 VERSION)
;==========================================================

mov esi,[BaseData]

;==========================================================
;open INI file and prepare for scanning
;==========================================================
invoke CreateFile,INIname,GENERIC_READ,0,0,OPEN_EXISTING,\
			FILE_ATTRIBUTE_NORMAL,0
	cmp eax,-1
	    jz NotOpened_INI
	mov [FileHandleINI],eax

invoke SetFilePointer,eax,0,0,FILE_BEGIN

invoke GetFileSize,[FileHandleINI],0
	cmp eax,-1
	    jz SizeError_INI
	cmp eax,6
	    jb NotOpened_INI  ;needs at least 6 bytes for a valid entry
	mov [FileSizeINI],eax

add eax,1
invoke LocalAlloc,LMEM_FIXED,eax  ;load entire file + 1 null-terminator
	test eax,eax
	     jz AllocError_INI
	mov [TempMemINI],eax

invoke ReadFile,[FileHandleINI],eax,[FileSizeINI],TempVar,0
	test eax,eax		;read entire INI file into LocalAlloc mem
	     jz ReadError_INI
	mov eax,[FileSizeINI]
	cmp [TempVar],eax	;check for number of bytes read
	     jb ReadError_INI

;==========================================================
;main INI scan code (records last entry of one kind only)
;==========================================================

mov ebx,[FileSizeINI]
mov edi,[TempMemINI]
lea ebx,[edi+ebx-1]	;"=" needs to be at least 1 byte from EOF (2 bytes from end of buffer)
mov BYTE [ebx+1],20h	;ending space character
add edi,3		;need at least 4 bytes total from start before "="

MainLoopX_INI:
inc edi
cmp edi,ebx			;EOF?
    jnb EOF_INI
cmp BYTE [edi],"="
    jz EntryFound_INI
jmp MainLoopX_INI

WaitForEndOfLine_INI:
inc edi
cmp edi,ebx			;EOF?
    jnb EOF_INI
cmp BYTE [edi],0Dh		;if semicolon, skip to next line
    jnz WaitForEndOfLine_INI
jmp MainLoopX_INI

EntryFound_INI:
mov eax,[edi-4]

cmp eax,'INTR'			;not inverted in FASM
	jz _intervalentry_INI
cmp eax,'GSPD'
	jz _fastentry_INI
cmp eax,'SLOW'
	jz _slowentry_INI
cmp eax,'GRAV'
	jz _usegravity_INI
cmp eax,'WNDO'
	jz _usewindowed_INI
cmp eax,'MXTB'
	jz _usemxtbite_INI
cmp eax,'MXTR'
	jz _usemxtbiteradius_INI
cmp eax,'DRAW'
	jz _usedrawdistance_INI
cmp eax,'SDBG'
	jz _usetresstrdbg_INI
cmp eax,'DEMS'
	jz _usedemohack_INI
cmp eax,'AINB'
	jz _usedisableactgetout
cmp eax,'STNR'
	jz _usedisableactstaynear
cmp eax,'STAW'
	jz _usedisableactstayaway
cmp eax,'FREZ'
	jz _useforcewakesleep
cmp eax,'DSWP'
	jz _usedisableswpdelete
cmp eax,'DPTS'
	jz _usedinohitpoints
cmp eax,'RAND'
	jz _userandomdinolocations
cmp eax,'FLYS'
	jz _useruserflyspeed
cmp eax,'FLYD'
	jz _useruserflydelayspeed

cmp eax,'KTOG'
	jz _usetoggleusenewkeys
cmp eax,'KMAP'
	jz _useusermapkey
cmp eax,'KDOM'
	jz _useuserdinomapkey
cmp eax,'KDRS'
	jz _useuserdrawsubkey
cmp eax,'KDRA'
	jz _useuserdrawaddkey
cmp eax,'KCAN'
	jz _userusercanimalkey
cmp eax,'KMSE'
	jz _userusermselkey
cmp eax,'KCAL'
	jz _userusercanimalleftkey
cmp eax,'KCAR'
	jz _userusercanimalrightkey

jmp MainLoopX_INI

_intervalentry_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,DefaultInterval
	add esp,12
		cmp [DefaultInterval],0
		    jnz MainLoopX_INI
		mov [DefaultInterval],DefaultInterval_CONST
	jmp MainLoopX_INI

_fastentry_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,NormalGameSpeed
	add esp,12
	jmp MainLoopX_INI

_slowentry_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,DefaultSlowSpeed
	add esp,12
		cmp [DefaultSlowSpeed],0
		jnz MainLoopX_INI
		mov [DefaultSlowSpeed],DefaultSlowSpeed_CONST
	jmp MainLoopX_INI

_usegravity_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseGRAVITY
	add esp,12
	jmp MainLoopX_INI

_usemxtbite_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseMXTBITE
	add esp,12
	jmp MainLoopX_INI

_usemxtbiteradius_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseMXTRadius
	add esp,12
	    cmp [UseMXTRadius],0
		jnz MainLoopX_INI
	    mov [UseMXTRadius],DWORD DefaultMXTRadius
	jmp MainLoopX_INI

_usedrawdistance_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseDRAWDISTANCE
	add esp,12
	jmp MainLoopX_INI

_usewindowed_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseWINDOWED
	add esp,12
	jmp MainLoopX_INI

_usetresstrdbg_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseTRESSTRDBG
	add esp,12
	jmp MainLoopX_INI

_usedemohack_INI:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseDEMOHACK
	add esp,12
	jmp MainLoopX_INI

_usedisableactgetout:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseNoGetOut
	add esp,12
	jmp MainLoopX_INI

_usedisableactstaynear:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseNoStayNear
	add esp,12
	jmp MainLoopX_INI

_usedisableactstayaway:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseNoStayAway
	add esp,12
	jmp MainLoopX_INI

_useforcewakesleep:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseSleepWake
	add esp,12
	jmp MainLoopX_INI

_usedisableswpdelete:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseDisableSWPDelete
	add esp,12
	jmp MainLoopX_INI

_usedinohitpoints:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseCAnimalHitPoints
	add esp,12
	jmp MainLoopX_INI

_userandomdinolocations:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseRandomDinoLocations
	add esp,12
	jmp MainLoopX_INI

_useruserflyspeed:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_float,UseFlySpeed
	add esp,12
	    cmp [UseFlySpeed],0
		jnz UserFlySpeedCustom
	    mov [UseFlySpeed],default_normal_fly_speed
	    UserFlySpeedCustom:
	    fld [float_two]
	    fmul [UseFlySpeed]
	    fstp [UseFlySpeed_Fast]
	jmp MainLoopX_INI

_useruserflydelayspeed:
	SKIP_SPACE_INI edi
	invoke sscanf,edi,_integer,UseFlyKeyDelay
	add esp,12
	cmp [UseFlyKeyDelay],0
	    jnz MainLoopX_INI
	    mov [UseFlyKeyDelay],default_key_fly_delay
	jmp MainLoopX_INI

;======================================
	MACRO SETKEYINI destvar {
	      SKIP_SPACE_INI edi
	      xor eax,eax
	      mov al,[edi]
	      cmp al,30h
		  jz MainLoopX_INI
	      mov destvar,eax
	      jmp MainLoopX_INI
	}

_usetoggleusenewkeys:
	SETKEYINI [UseToggleNewKeys]
_useusermapkey:
	SETKEYINI [UseUserMapKey]
_useuserdinomapkey:
	SETKEYINI [UseUserMDinoKey]
_useuserdrawsubkey:
	SETKEYINI [UseDrawDistSubKey]
_useuserdrawaddkey:
	SETKEYINI [UseDrawDistAddKey]

_userusercanimalkey:
	SETKEYINI [UseCANIMALKey]
_userusermselkey:
	SETKEYINI [UseUserMSelKey]
_userusercanimalleftkey:
	SETKEYINI [UseUserCANIMALLEFTKey]
_userusercanimalrightkey:
	SETKEYINI [UseUserCANIMALRIGHTKey]

EOF_INI:
	invoke LocalFree,[TempMemINI]
	xor ebp,ebp
	jmp INI_Success

;==========================================================
;end main INI code
;==========================================================

ReadError_INI:
	invoke LocalFree,[TempMemINI]
AllocError_INI:
SizeError_INI:
	mov ebp,1
NotOpened_INI:
	mov ebp,2
INI_Success:

	CLOSEHANDLE [FileHandleINI]

	WRITELOG_NOEXIT _message2




